<?php

namespace App\Http\Controllers;

use App\Models\Aboutus;
use App\Models\Banners;
use App\Models\Blogimages;
use App\Models\Blogs;
use App\Models\Blogs_tags;
use App\Models\Blogscategories;
use App\Models\Ourpartners;
use App\Models\Setting;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Carbon\Carbon;
use Illuminate\Support\Str;
use Intervention\Image\ImageManagerStatic as Image;

class BlogsController extends Controller
{
    public function blogsbanner()
    {
        $banner = Banners::where('id', 3)->first();
        return view("admin.blogsbanner", compact('banner'));
    }

    public function updateblogsbanner(Request $request)
    {
        $getData = Banners::where('id', 3)->first();
        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Invalid Banner');
            }

            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }

            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }

        $getData->save();
        return back()->with('success', 'Successfully Updated !');
    }

    public function blogcategories()
    {
        $blogscategories = Blogscategories::all();
        return view("admin.blogcategories", compact('blogscategories'));
    }

    public function saveblogcategory(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:255',
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'Category Name Required !');
        }

        $data['name'] = $request->name;
        Blogscategories::create($data);
        return back()->with('success', 'Data Successfully Added !');
    }

    public function updateblogcategory(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:255',
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'Category Name Required !');
        } else {
            $getData = Blogscategories::findOrFail(decrypt($request->id));
            if (isset($request->name)) {
                $getData->name = $request->name;
            }
            $getData->save();
        }
        return back()->with('success', 'Successfully Updated !');
    }

    public function deleteblogcategory($id)
    {
        $getData = Blogscategories::findOrFail(decrypt($id));
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function addblogs()
    {
        $categories = Blogscategories::all();
        $setting = Setting::first();
        return view("admin.addblogs", compact('categories', 'setting'));
    }

    public function saveblogs(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'categoryid' => 'required|numeric',
            'heading' => 'required|string|max:255',
            'status' => 'required',
            'tags' => 'required',
            'description' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All fields Required .');
        }
        $validator1 = Validator::make($request->all(), [
            'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
        ]);

        if ($validator1->fails()) {
            return back()->with('error', 'Image Must be in jpg,png,jpeg,gif,svg.');
        }

        $data['heading'] = $request->heading;
        $data['categoryid'] = $request->categoryid;
        $data['description'] = $request->description;
        $data['status'] = $request->status;
        $data['tags'] = $request->tags;
        $data['slug'] = Str::slug($request->heading);

//        check slug already exist
        $CheckSlug = Blogs::where('slug', Str::slug($request->heading))->count();
        if ($CheckSlug > 0) {
            return back()->with('error', 'This heading is already exist .');
        }

        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
        }
        $bloddetail = Blogs::create($data);
        return redirect()->route('admin.blogslist')->with('success', 'Data Successfully Added !');
    }

    public function blogslist()
    {
        $blogs = Blogs::with(['category_data'])->orderBy('id', 'desc')->get();
        return view('admin.blogs', compact('blogs'));
    }

    public function deleteblog($id)
    {
        $getData = Blogs::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }

        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function editblog($id)
    {
        $blog = Blogs::findOrFail(decrypt($id));
        $categories = Blogscategories::all();
        $setting = Setting::first();
        return view('admin.editblogs', compact('blog', 'categories', 'setting'));
    }

    public function updateblogs(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'categoryid' => 'required|numeric',
            'heading' => 'required|string|max:255',
            'status' => 'required',
            'tags' => 'required',
            'id' => 'required',
            'description' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'Heading , Category and Description Required .');
        }

        $getData = Blogs::findOrFail(decrypt($request->id));
        if (isset($request->heading)) {
            $getData->heading = $request->heading;
        }
        if (isset($request->categoryid)) {
            $getData->categoryid = $request->categoryid;
        }
        if (isset($request->description)) {
            $getData->description = $request->description;
        }
        if (isset($request->status)) {
            $getData->status = $request->status;
        }
        if (isset($request->status)) {
            $getData->status = $request->status;
        }
        if (isset($request->tags)) {
            $getData->tags = $request->tags;
        }

        $CheckSlug = Blogs::where('slug', Str::slug($request->heading))->where('id', '!=', decrypt($request->id))->count();
        if ($CheckSlug > 0) {
            return back()->with('error', 'This heading is already exist .');
        } else {
            $getData->slug = Str::slug($request->heading);
        }

        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);
            if ($validator->fails()) {
                return back()->with('error', 'Invalid Image');
            }
            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }
        $getData->save();
        return redirect()->route('admin.blogslist')->with('success', 'Data Successfully Updated !');
    }

    public function editimages($id)
    {
        $blog = Blogs::findOrFail(decrypt($id));
        return view('admin.editimages', compact('blog'));
    }

    public function savesblogimage(Request $request)
    {
        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg',
                'blogid' => 'required'
            ]);
        }

        if ($validator->fails()) {
            return back()->with('error', 'Image Is Required');
        }
        $data['blogid'] = $request->blogid;

        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
        }

        Blogimages::create($data);
        return back()->with('success', 'Data Successfully Added !');
    }

    public function updateblogimage(Request $request)
    {
        $getData = Blogimages::findOrFail(decrypt($request->id));

        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Invalid image Type');
            }

            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }

            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }
        $getData->save();
        return back()->with('success', 'Successfully Updated !');
    }

    public function deleteblogimage($id)
    {
        $getData = Blogimages::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

}
