<?php

namespace App\Http\Controllers;

use App\Models\Categories;
use App\Models\ContactMessage;
use App\Models\Lectures;
use App\Models\Orders;
use App\Models\ProductImages;
use App\Models\PracticeLectures;
use App\Models\Products;
use App\Models\Setting;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;


class ManageWebsiteFunctionality extends Controller
{

    public function categories()
    {
        $categories = Categories::orderBy('id', 'desc')->get();
        return view("admin.categories", compact('categories'));
    }

    public function savecategories(Request $request)
    {
        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg,webp',
                'name' => 'required'
            ]);
        }

        if ($validator->fails()) {
            return back()->with('error', 'Name & Image Is Required');
        }
        $data['name'] = $request->name;

        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
        }

        Categories::create($data);
        return back()->with('success', 'Data Successfully Added !');
    }

    public function updatecategory(Request $request)
    {
        $getData = Categories::findOrFail(decrypt($request->id));

        if (isset($request->name)) {
            $getData->name = $request->name;
        }
        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg,webp'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Invalid image');
            }

            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }

            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }
        $getData->save();
        return back()->with('success', 'Successfully Updated !');
    }

    public function deletecategory($id)
    {
        $getData = Categories::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function products()
    {
        $products = Products::orderBy('id', 'desc')->get();
        return view("admin.products", compact('products'));
    }

    public function add_products()
    {
        $categories = array();
        return view("admin.add_products", compact('categories'));
    }

    public function save_products(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'price' => 'required',
            'categoryid' => 'required',
            'stock' => 'required',
            'tags' => 'required',
            'description' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        $data['name'] = $request->name;
        $data['price'] = $request->price;
        if (isset($request->cut_price) && !empty($request->cut_price)) {
            $data['cut_price'] = $request->cut_price;
        }
        $data['categoryid'] = $request->categoryid;
        $data['stock'] = $request->stock;
        $data['tags'] = $request->tags;
        $data['description'] = $request->description;
        $data['slug'] = Str::slug($request->name);
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
        }
        $CheckSlug = Products::where('slug', Str::slug($request->name))->count();
        if ($CheckSlug > 0) {
            return back()->with('error', 'This Name is already exist .');
        }
        $productdetail = Products::create($data);

        if ($request->hasFile('MoreImages')) {
            $imagessize = sizeof($request->MoreImages);
            for ($i = 0; $i < $imagessize; $i++) {
                $image = $request->file('MoreImages')[$i];
                $image_new = time() . $image->getClientOriginalName();
                $image->move('admin/assets/uploads/', $image_new);
                $ProductData['image'] = $image_new;
                $ProductData['productid'] = $productdetail->id;;
                ProductImages::create($ProductData);
            }

        }
        return redirect()->route('admin.products')->with('success', 'Product Added Successfully');
    }

    public function delete_product($id)
    {
        $getData = Products::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }

        if (!empty($getData->images)) {
            foreach ($getData->images as $images_image) {
                if (\File::exists(public_path('admin/assets/uploads/' . $images_image->image))) {
                    \File::delete(public_path('admin/assets/uploads/' . $images_image->image));
                }
            }
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function edit_product($id)
    {
        $product = Products::findOrFail(decrypt($id));
        $categories = array();
        return view('admin.edit_product', compact('product', 'categories'));
    }

    public function update_products(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required',
            'name' => 'required',
            'price' => 'required',
            'categoryid' => 'required',
            'stock' => 'required',
            'tags' => 'required',
            'description' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        $getData = Products::findOrFail($request->id);
        $getData->name = $request->name;
        $getData->price = $request->price;
        $getData->categoryid = $request->categoryid;
        $getData->stock = $request->stock;
        $getData->tags = $request->tags;
        if (isset($request->cut_price) && !empty($request->cut_price)) {
            $getData->cut_price = $request->cut_price;
        }
        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);

            if ($validator->fails()) {
                return back()->withInput()->with('error', 'Invalid Property image');
            }
            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }
        $getData->update();
        return redirect()->route('admin.products')->with('success', 'Product Successfully Updated');
    }

    public function edit_product_images($id)
    {
        $product = Products::findOrFail(decrypt($id));
        return view('admin.edit_product_images', compact('product'));
    }

    public function contact_messages()
    {
        $contact_messages = ContactMessage::all();
        return view("admin.contact_messages", compact('contact_messages'));
    }

    public function delete_contact_message($id)
    {
        $getData = ContactMessage::findOrFail(decrypt($id));
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function terms_condition()
    {
        $setting = Setting::first();
        return view('admin.terms_condition', compact('setting'));
    }

    public function update_terms_condition(Request $request)
    {
        $setting = Setting::first()->update(["terms_condition" => $request->terms_condition]);
        return redirect()->back()->with('success', 'Successfully Updated');
    }

    public function privacy_policy()
    {
        $setting = Setting::first();
        return view('admin.privacy_policy', compact('setting'));
    }

    public function update_privacy_policy(Request $request)
    {
        $setting = Setting::first()->update(["privacy" => $request->privacy]);
        return redirect()->back()->with('success', 'Successfully Updated');
    }

    public function lectures(Request $request)
    {
        $lectures = Lectures::all();
        return view('admin.lectures', compact('lectures'));
    }

    public function addlectures(Request $request)
    {
        return view('admin.addlectures');
    }

    public function savelecture(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'heading' => 'required',
            'lectureby' => 'required',
            'category' => 'required',
            'tags' => 'required',
            'description' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All fields Required .');
        }
        $validator1 = Validator::make($request->all(), [
            'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
        ]);

        if ($validator1->fails()) {
            return back()->with('error', 'Image Must be in jpg,png,jpeg,gif,svg.');
        }

        $data['heading'] = $request->heading;
        $data['lectureby'] = $request->lectureby;
        $data['category'] = $request->category;
        $data['tags'] = $request->tags;
        $data['description'] = $request->description;
        $data['slug'] = Str::slug($request->heading);
        if (isset($request->link)) {
            $data['link'] = $request->link;
        }

//        check slug already exist
        $CheckSlug = Lectures::where('slug', Str::slug($request->heading))->count();
        if ($CheckSlug > 0) {
            return back()->with('error', 'This heading is already exist .');
        }

        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
        }
        $Lecturesdetail = Lectures::create($data);
        return redirect()->route('admin.lectures')->with('success', 'Data Successfully Added !');
    }

    public function deletelecture($id)
    {
        $getData = Lectures::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function editlecture($id)
    {
        $lecture = Lectures::findOrFail(decrypt($id));
        return view('admin.editlecture', compact('lecture'));
    }

    public function updatelecture(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required',
            'heading' => 'required',
            'lectureby' => 'required',
            'category' => 'required',
            'link' => 'required',
            'tags' => 'required',
            'description' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'Heading , Category and Description Required .');
        }

        $getData = Lectures::findOrFail($request->id);
        if (isset($request->heading)) {
            $getData->heading = $request->heading;
        }
        if (isset($request->lectureby)) {
            $getData->lectureby = $request->lectureby;
        }
        if (isset($request->category)) {
            $getData->category = $request->category;
        }
        if (isset($request->tags)) {
            $getData->tags = $request->tags;
        }
        if (isset($request->description)) {
            $getData->description = $request->description;
        }
        if (isset($request->link)) {
            $getData->link = $request->link;
        }
        $CheckSlug = Lectures::where('slug', Str::slug($request->heading))->where('id', '!=', $request->id)->count();
        if ($CheckSlug > 0) {
            return back()->with('error', 'This heading is already exist .');
        } else {
            $getData->slug = Str::slug($request->heading);
        }

        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);
            if ($validator->fails()) {
                return back()->with('error', 'Invalid Image');
            }
            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }
        $getData->save();
        return redirect()->route('admin.lectures')->with('success', 'Data Successfully Updated !');
    }

    public function users_list()
    {
        $users = User::where('type', 'user')->get();
        return view("admin.users_list", compact('users'));
    }

    public function active_inactive($id)
    {
        $user = User::findOrFail(decrypt($id));
        if ($user->status == "active") {
            $user->status = "inactive";
        } else {
            $user->status = "active";
        }
        $user->update();
        return back()->with('success', 'Successfully Updated !');
    }

    public function addpracticelectures()
    {
        return view("admin.addpracticelectures");
    }

    public function savepracticelectures(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'heading' => 'required',
            'link' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All fields Required .');
        }
        $validator1 = Validator::make($request->all(), [
            'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
        ]);

        if ($validator1->fails()) {
            return back()->with('error', 'Image Must be in jpg,png,jpeg,gif,svg.');
        }

        $data['heading'] = $request->heading;
        $data['link'] = $request->link;
        $data['slug'] = Str::slug($request->heading);

//        check slug already exist
        $CheckSlug = PracticeLectures::where('slug', Str::slug($request->heading))->count();
        if ($CheckSlug > 0) {
            return back()->with('error', 'This heading is already exist .');
        }

        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
        }
        PracticeLectures::create($data);
        return redirect()->route('admin.practicelectureslist')->with('success', 'Data Successfully Added !');
    }


    public function practicelectureslist()
    {
        $lists = PracticeLectures::all();
        return view("admin.practicelectureslist",compact('lists'));
    }

    public function deletepracticelecture($id)
    {
        $getData = PracticeLectures::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function updatepracticerecord(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'id' => 'required',
            'heading' => 'required',
            'link' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        $getData = PracticeLectures::findOrFail(decrypt($request->id));
        $getData->link = $request->link;
        $getData->heading = $request->heading;
        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);

            if ($validator->fails()) {
                return back()->withInput()->with('error', 'Invalid image');
            }
            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }
        $getData->update();
        return redirect()->route('admin.practicelectureslist')->with('success', 'Record Successfully Updated');
    }


}
