<?php

namespace App\Http\Controllers;

use App\Mail\PasswordResetMail;
use App\Models\Blogs;
use App\Models\Blogscategories;
use App\Models\CommunityChat;
use App\Models\ContactMessage;
use App\Models\PracticeLectures;
use App\Models\Lectures;
use App\Models\Setting;
use App\Models\User;
use App\Notifications\MessageNotification;
use Hamcrest\Core\Set;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;

class WebsiteController extends Controller
{
    public function home()
    {
        $lectures = Lectures::limit(3)->orderBy('id', 'desc')->get();
        $blogs = Blogs::limit(3)->orderBy('id', 'desc')->get();
        return view("website.home", compact('lectures', 'blogs'));
    }

    public function contact()
    {
        $setting = Setting::first();
        return view("website.contact", compact('setting'));
    }

    public function practice()
    {
        $pts = PracticeLectures::get();
        return view("website.practice", compact('pts'));
    }

    public function save_contact_message(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required',
            'phone' => 'required',
            'subject' => 'required',
            'message' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        $data['name'] = $request->name;
        $data['email'] = $request->email;
        $data['phone'] = $request->phone;
        $data['subject'] = $request->subject;
        $data['message'] = $request->message;
        ContactMessage::create($data);
        return redirect()->back()->with('success', 'Successfully Submitted.');
    }

    public function about()
    {
        return view("website.about");
    }

    public function login()
    {
        $system = Setting::first();
        return view("website.login", compact('system'));
    }

    public function customerlogin(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required',
            'password' => 'required|min:8'
        ]);
        if ($validator->fails()) {
            return back()->withInput()->withErrors($validator);
        }
        if (Auth::guard('web')->attempt(['email' => $request->email, 'password' => $request->password, 'type' => 'user'])) {
            if (Auth::guard('web')->user()->status == "inactive") {
                Auth::guard('web')->logout();
                return redirect()->back()->with('error', 'Account Inactive / Blocked ! Please Contact with Customer support.')->withErrors("Account Inactive / Blocked ! Please Contact with Customer support.");
            } else {
                if (Auth::guard('web')->check()) {
                    return redirect()->route('/');
                }
            }
        } else {
            return redirect()->back()->with('error', 'Invalid Email or Password !')->withInput()->withErrors("Invalid Email or Password !");
        }
    }

    public function customerlogout(Request $request)
    {
        Auth::guard('web')->logout();
        return redirect()->route('/')->with('success', 'Successfully Logout.');
    }

    public function profile()
    {
        return view("website.profile");
    }

    public function updateuserprofile(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required',
            'phone' => 'required'
        ]);
        if ($validator->fails()) {
            return back()->with('error', 'All Fields required.');
        }
        $getData = User::findOrFail(Auth::guard('web')->user()->id);
        $getData->name = $request->name;
        $getData->phone = $request->phone;
        if (isset($request->email) && !empty($request->email)) {
            $validator = Validator::make($request->all(), [
                'email' => [
                    'required',
                    Rule::unique('users')->ignore(Auth::guard('web')->user()->id),
                ],
            ]);
            if ($validator->fails()) {
                return back()->with('error', 'Email already exist.');
            }
        }
        if (isset($request->password)) {
            $validator = Validator::make($request->all(), [
                'password' => 'required|string|min:8'
            ]);
            if ($validator->fails()) {
                return back()->with('error', 'Please Enter Valid Password !');
            }
            $getData->password = Hash::make($request->password);
        }

        $getData->update();
        return redirect()->back()->with('success', 'Successfully Updated.');
    } //call profile view page

    public function signup()
    {
        $system = Setting::first();
        return view("website.signup", compact('system'));
    }

    public function save_register_user(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'phone' => 'required',
            'email' => 'required|unique:users,email',
            'password' => 'min:8|required_with:password_confirmation|same:password_confirmation',
            'password_confirmation' => 'min:8'
        ]);
        if ($validator->fails()) {
            return back()
                ->withInput()
                ->withErrors($validator);
        }
        $data['name'] = $request->name;
        $data['email'] = $request->email;
        $data['phone'] = $request->phone;
        $data['status'] = "active";
        $data['password'] = Hash::make($request->password);
        $userdata = User::create($data);
        return redirect()->route('login')->with('success', 'Successfully Registered.');
    }

    public function community()
    {
        event(new MessageNotification("1"));
        return view("website.community");
    }

    public function save_chat_message(Request $request)
    {
        $data['userid'] = Auth::guard('web')->user()->id;
        $data['message'] = $request->chat_message;
        $data['send_by'] = Auth::guard('web')->user()->id;
        $check = CommunityChat::create($data);
        if($check)
        {
            event(new MessageNotification($request->all()));
            return response()->json(['success' => true]);
        }
        else
        {
            return response()->json(['success' => false]);
        }
    }

    public function load_community_chat()
    {
        $chats = CommunityChat::with('userdata')->orderBy('id', 'asc')->get();
        return response()->json($chats);
    }

    public function bind_channel()
    {
        $data = event(new MessageNotification("Bind Channel"));
        return $data;
    }

    public function forgot()
    {
//        $maildata = User::findOrFail(92);
//        return view("website.resetpassword",compact('maildata'));
        return view("website.forgot");
    }

    public function resetpassword(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required'
        ]);
        if ($validator->fails()) {
            return back()
                ->withInput()
                ->withErrors($validator)->with('error', 'Email Required.');
        }

        $check = User::where('email', $request->email)->where('type', 'user')->first();
        $setting = Setting::first();
        if ($check) {
            if ($check->status == "active") {

                $check->remember_token = Str::random(30);
                $check->save();
                $maildata = $check;
                Mail::to($request->email)->send(new PasswordResetMail($check));
                return redirect()->route('login')->with('success', 'Password Sent ! Please Check your email address !')->with('success', 'Password Sent ! Please Check your email address !');
            } else {
                return back()
                    ->withInput()
                    ->withErrors('Your account is not active please contact with customer support.')->with('error', 'Your account is not active please contact with customer support.');
            }
        } else {
            return back()
                ->withInput()
                ->withErrors('Invalid email !Please enter valid email ')->with('error', 'Invalid Email.');
        }

    }

    public function resetnewpassword($email)
    {
        $decemail = decrypt($email);
        $check = User::where('email', $decemail)->whereNotNull('remember_token')->count();
        if ($check > 0) {
            return view('website.resetnewpassword', compact('email'));
        } else {
            return redirect()->route('login')->with('error', 'Link Expired Please Reset Your Password Again !');
        }
    }

    public function saveresetnewpassword(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'password' => 'min:8|required_with:password_confirmation|same:password_confirmation',
            'password_confirmation' => 'min:8'
        ]);
        if ($validator->fails()) {
            return back()
                ->withInput()
                ->withErrors($validator)->with('error', 'Password Not Match / Required.');
        }

        $email = decrypt($request->id);
        $user = User::where('email', $email)->first();
        $user->password = Hash::make($request->password);;
        $user->remember_token = NULL;
        $user->save();
        return redirect()->route('login')->with('success', 'Password Successfully Updated !')->with('success', 'Password Successfully Updated.');
    }

    public function privacy()
    {
        $setting = Setting::first();
        return view("website.privacy", compact('setting'));
    }

    public function terms()
    {
        $setting = Setting::first();
        return view("website.terms", compact('setting'));
    }

    public function lecture(Request $request)
    {
        $query = Lectures::query();
        if (isset($request->heading)) {
            $query->where('heading', 'like', '%' . $request->heading . '%');
        }
        $lectures = $query->get();
        return view("website.lecture", compact('lectures'));
    }

    public function lecturedetails($slug)
    {
        $lectures = Lectures::where('slug', $slug)->first();
        return view("website.lecturedetails", compact('lectures'));
    }

    public function blog(Request $request)
    {
        $query = Blogs::query();
        if (isset($request->categoryid)) {
            $query->where('categoryid', $request->categoryid);
        }
        if (isset($request->heading)) {
            $query->where('heading', 'like', '%' . $request->heading . '%');
        }
        $blogs = $query->get();
        return view("website.blog", compact('blogs'));
    }

    public function blogdetails($slug)
    {
        $blog_categories = Blogscategories::all();
        $blog = Blogs::where('slug', $slug)->first();
        $admin = User::where('type', 'admin')->first();
        return view("website.blogdetails", compact('blog', 'blog_categories', 'admin'));
    }


}
